searchData={"items":[{"type":"module","title":"Argon2","doc":"Argon2 password hashing for Elixir using Rust NIFs.\n\nThis module provides a secure way to hash passwords using the Argon2i algorithm\nwith configuration presets following security best practices.","ref":"Argon2.html"},{"type":"module","title":"Security Presets - Argon2","doc":"* `:owasp` (default) - OWASP recommended settings (m=19456, t=2, p=1)\n* `:strong` - Higher security settings (m=65540, t=3, p=4)\n* `:test_unsafe` - Fast settings for testing only (m=1024, t=1, p=1)","ref":"Argon2.html#module-security-presets"},{"type":"module","title":"Examples - Argon2","doc":"# Hash with default OWASP settings\n    iex> hash = Argon2.hash_password(\"secure_password123\")\n    iex> String.starts_with?(hash, \"$argon2i$v=19$m=19456,t=2,p=1$\")\n    true\n\n    # Hash with strong settings\n    iex> hash = Argon2.hash_password(\"secure_password123\", \"strong\")\n    iex> String.starts_with?(hash, \"$argon2i$v=19$m=65540,t=3,p=4$\")\n    true\n\n    # Verify password\n    iex> hash = Argon2.hash_password(\"secure_password123\")\n    iex> Argon2.verify_password(\"secure_password123\", hash)\n    true\n    iex> Argon2.verify_password(\"wrong_password\", hash)\n    false","ref":"Argon2.html#module-examples"},{"type":"module","title":"Security Notes - Argon2","doc":"* Passwords must be at least 8 characters long\n* Each hash uses a unique random salt\n* The `:test_unsafe` preset should never be used in production","ref":"Argon2.html#module-security-notes"},{"type":"function","title":"Argon2.hash_password/2","doc":"Hashes a password using Argon2i.","ref":"Argon2.html#hash_password/2"},{"type":"function","title":"Options - Argon2.hash_password/2","doc":"* `config` - One of `\"owasp\"` (default), `\"strong\"`, or `\"test_unsafe\"`","ref":"Argon2.html#hash_password/2-options"},{"type":"function","title":"Examples - Argon2.hash_password/2","doc":"iex> hash = Argon2.hash_password(\"secure_password123\")\n    iex> is_binary(hash)\n    true","ref":"Argon2.html#hash_password/2-examples"},{"type":"function","title":"Security Notes - Argon2.hash_password/2","doc":"* Passwords must be at least 8 characters\n* A unique random salt is used for each hash\n* The default OWASP preset is recommended for most use cases\n\nRaises `ArgumentError` if the password is less than 8 characters long.","ref":"Argon2.html#hash_password/2-security-notes"},{"type":"function","title":"Argon2.verify_password/2","doc":"Verifies a password against a hash.\n\nTakes constant time regardless of whether the password matches or not.","ref":"Argon2.html#verify_password/2"},{"type":"function","title":"Examples - Argon2.verify_password/2","doc":"iex> hash = Argon2.hash_password(\"secure_password123\")\n    iex> Argon2.verify_password(\"secure_password123\", hash)\n    true\n\nRaises `ArgumentError` if:\n* The password is less than 8 characters long\n* The hash format is invalid","ref":"Argon2.html#verify_password/2-examples"},{"type":"type","title":"Argon2.config/0","doc":"","ref":"Argon2.html#t:config/0"},{"type":"type","title":"Argon2.hash/0","doc":"","ref":"Argon2.html#t:hash/0"},{"type":"type","title":"Argon2.password/0","doc":"","ref":"Argon2.html#t:password/0"},{"type":"module","title":"Argon2.Native","doc":"Native implementation of the Argon2 password hashing algorithm.","ref":"Argon2.Native.html"},{"type":"function","title":"Argon2.Native.hash_password/2","doc":"","ref":"Argon2.Native.html#hash_password/2"},{"type":"function","title":"Argon2.Native.verify_password/2","doc":"","ref":"Argon2.Native.html#verify_password/2"},{"type":"module","title":"Argon2.Benchmark","doc":"Benchmarking utilities for Argon2 password hashing.\n\nHelps you determine appropriate parameters for your use case by measuring\nexecution time of different configurations.","ref":"Argon2.Benchmark.html"},{"type":"function","title":"Argon2.Benchmark.run/1","doc":"Runs benchmarks for different Argon2 configurations.","ref":"Argon2.Benchmark.html#run/1"},{"type":"function","title":"Examples - Argon2.Benchmark.run/1","doc":"iex> Argon2.Benchmark.run()\n    Configuration Benchmarks (averaged over 5 runs):\n    \n    OWASP (default):\n      Hash time: 285ms\n      Verify time: 280ms\n      Memory: 19MB\n    \n    Strong:\n      Hash time: 890ms\n      Verify time: 885ms\n      Memory: 65MB\n    \n    Test (unsafe):\n      Hash time: 25ms\n      Verify time: 23ms\n      Memory: 1MB","ref":"Argon2.Benchmark.html#run/1-examples"},{"type":"extras","title":"Argon2id for Elixir","doc":"# Argon2id for Elixir\n\nFast and secure Argon2 password hashing library for Elixir.","ref":"readme.html"},{"type":"extras","title":"Features - Argon2id for Elixir","doc":"- Uses the pure Rust implementation of Argon2\n- Only Argon2i implementation (version 0x13) at the moment\n- Built-in security presets (OWASP, Strong, Test/Unsafe)","ref":"readme.html#features"},{"type":"extras","title":"Installation - Argon2id for Elixir","doc":"Add `argon2id_elixir` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:argon2id_elixir, \"~> 0.1.0\"}\n  ]\nend\n```\n\nEnsure you have Rust installed, as it's required for compilation:\n\n```bash\n# On Windows\nwinget install Rust.Rust\n\n# On Unix-like systems (https://rustup.rs/)\ncurl --proto '=https' --tlsv1.2 -sSf https://sh.rustup.rs | sh\n```","ref":"readme.html#installation"},{"type":"extras","title":"Usage - Argon2id for Elixir","doc":"","ref":"readme.html#usage"},{"type":"extras","title":"Basic Password Hashing - Argon2id for Elixir","doc":"```elixir\n# Hash a password with default OWASP settings\nhash = Argon2.hash_password(\"secure_password123\")\n\n# Verify a password\nif Argon2.verify_password(\"secure_password123\", hash) do\n  # Password matches\nelse\n  # Password is incorrect\nend\n```","ref":"readme.html#basic-password-hashing"},{"type":"extras","title":"Configuration Presets - Argon2id for Elixir","doc":"Three security presets are available:\n\n```elixir\n# OWASP (default) - Recommended for most use cases\nhash = Argon2.hash_password(\"secure_password123\")\n\n# Strong - Higher security for sensitive applications\nhash = Argon2.hash_password(\"secure_password123\", \"strong\")\n\n# Test - Fast but unsafe, only for testing purposes\nhash = Argon2.hash_password(\"secure_password123\", \"test_unsafe\")\n```\n\nPreset specifications:\n- OWASP: m=19456 KiB, t=2, p=1\n- Strong: m=65540 KiB, t=3, p=4\n- Test: m=1024 KiB, t=1, p=1 (Useful for testing)","ref":"readme.html#configuration-presets"},{"type":"extras","title":"Benchmarking - Argon2id for Elixir","doc":"You can benchmark the different configurations on your hardware:\n\n```bash\nmix run -e \"Argon2.Benchmark.run(10)\"\n```\n\n```elixir\nConfiguration Benchmarks (averaged over 10 runs):\n\nOWASP:\n  Hash time: 25ms\n  Verify time: 24ms\n  Memory: 19MB\n\nSTRONG:\n  Hash time: 145ms\n  Verify time: 139ms\n  Memory: 65MB\n\nTEST_UNSAFE:\n  Hash time: 1ms\n  Verify time: 1ms\n  Memory: 1MB\n```","ref":"readme.html#benchmarking"},{"type":"extras","title":"Development - Argon2id for Elixir","doc":"```bash\n# Install dependencies\nmix deps.get\n\n# Run tests\nmix test\n\n# Run benchmarks\nmix run -e \"Argon2.Benchmark.run()\"\n\n# Run code quality checks\nmix quality\n\n# Generate documentation\nmix docs\n\n# Format code\nmix format\n```","ref":"readme.html#development"},{"type":"extras","title":"License - Argon2id for Elixir","doc":"Licensed under either of\n\n- Apache License, Version 2.0, ([LICENSE-APACHE](LICENSE-APACHE) or http://www.apache.org/licenses/LICENSE-2.0)\n- MIT license ([LICENSE-MIT](LICENSE-MIT) or http://opensource.org/licenses/MIT)\n\nat your option.","ref":"readme.html#license"},{"type":"extras","title":"Credits - Argon2id for Elixir","doc":"- [RustCrypto Argon2](https://github.com/RustCrypto/password-hashes/tree/master/argon2) - The Rust implementation\n- [Rustler](https://github.com/rusterlium/rustler) - Elixir NIF interface","ref":"readme.html#credits"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}